@@ -1,3 +1,8 @@
+# Copyright (c) FlapMX LLC.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
+
 import json
 import logging
 import os
@@ -12,7 +17,8 @@ logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
 env = os.environ
-"""Provides all the task related information. 
+"""
+Provides all the task related information. 
 """
 celery_task_ns = Namespace('celery', description='All task related information')
 
@@ -76,8 +82,10 @@ class DownloadFile(Resource):
 
 
 def task_already_running(channel):
-    """Checks the number of tasks already runing. Returns true if its more than 2, otherwise false.
-        :param channel: channel that submitted that task
+    """
+    Checks the number of tasks already runing. Returns true if its more than 4, otherwise false.
+        
+    :param channel: channel that submitted that task
     """
     i = celery.control.inspect()
     if i.active() is not None:
@@ -93,7 +101,7 @@ def task_already_running(channel):
 
 parser = reqparse.RequestParser()
 parser.add_argument('page_size', type=int,
-                    help="number of records to return",
+                    help="number of records per page",
                     default=10, required=True)
 parser.add_argument('page_num', type=int,
                     help="the page identifier",
@@ -108,10 +116,9 @@ class TaskHistory(Resource):
         args = parser.parse_args()
         # Calculate number of documents to skip
         skips = args.get('page_size') * (args.get('page_num') - 1)
-        documents = mongo.db.celery_taskmeta.find().skip(skips).limit(args.get('page_size'))
+        documents = mongo.db.celery_taskmeta.find()
         taskList = []
         for history in documents:
-            logger.info(history.get('result'))
             if 'preview' in history.get('result'):
                 continue
             history['id'] = history.pop('_id')
@@ -119,7 +126,8 @@ class TaskHistory(Resource):
             history['model'] = result.get('model', '')
             history['task'] = result.get('task', '')
             taskList.append(history)
-        return taskList
+        # return taskList
+        return taskList[skips:skips+args.get('page_size')]
 
 
 @celery_task_ns.route('/search/<task_id>')
@@ -128,7 +136,28 @@ class GetTask(Resource):
     @celery_task_ns.doc('Get the task related to the specific task id ')
     def get(self, task_id):
         from bson.json_util import dumps
-        document = mongo.db.celery_taskmeta.find(
+        documents = mongo.db.celery_taskmeta.find(
             {'_id': {"$regex": task_id, "$options": "$i"}}
         )
-        return dumps(document)
+        taskList = []
+        documents = json.loads(dumps(documents))
+        logger.info(documents)
+        for document in documents:
+            logger.info(document)
+            document['id'] = document.pop('_id')
+            taskList.append(document)
+            logger.info(taskList)
+        return taskList
+
+
+@celery_task_ns.route('/history/total')
+class GetTask(Resource):
+    @celery_task_ns.doc('Get the total number of tasks')
+    def get(self):
+        documents = mongo.db.celery_taskmeta.find()
+        count = 0
+        for history in documents:
+            if 'preview' in history.get('result'):
+                continue
+            count = count+1
+        return count
\ No newline at end of file
