@@ -1,3 +1,8 @@
+# Copyright (c) FlapMX LLC.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
+
 from __future__ import absolute_import
 
 import json
@@ -93,9 +98,14 @@ class ModelPreview(Resource):
         with open(input_dest, 'r') as infile:
             head = list(islice(infile, num_lines))
 
+        # output file setup
+        output = os.path.join(env.get('OUTPUT_FOLDER'))
+        if not os.path.isdir(output):
+            os.makedirs(output)
+
         if not task_already_running(str(channel)):
             task = celery.send_task(model.split("_")[0]+'.preview',
-                                    args=[model, head])
+                                    args=[model, head, output])
             return url_for('task_status', task_id=task.id), 202, {}
         else:
             return "wait for the task to complete", 425, {}
