@@ -1,3 +1,8 @@
+# Copyright (c) FlapMX LLC.
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
+
 from flask import Flask
 from flask_restplus import Api
 
@@ -9,8 +14,11 @@ socketio = SocketIO()
 
 
 def create_app(debug=True):
-    """Create an application.
+    """
+    Create an application.
+    
     :param debug: whether to run Flask in debug Mode.
+    :type debug: boolean
     """
     app = Flask(__name__)
     CORS(app, resources={r"/*": {"origins": "*"}})
