@@ -1,32 +1,32 @@
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import React from "react";
 import { Bar, defaults } from "react-chartjs-2";
-import { Container } from "./styled-components";
 
-function dynamicColors() {
-  let r = Math.floor(Math.random() * 255);
-  let g = Math.floor(Math.random() * 255);
-  let b = Math.floor(Math.random() * 255);
-  return "rgba(" + r + "," + g + "," + b + ")";
-}
-
-function poolColors(a) {
+function poolColors(channelCount) {
+  let colors = ["#0033FF", "#0099FF", "#0066FF", "#00CCFF"];
   let pool = [];
-  for (let i = 0; i < a; i++) {
-    pool.push(dynamicColors());
+  for (let i = 0; i < channelCount; i++) {
+    pool[i] = colors[i];
   }
   return pool;
 }
 
 function BarChart(props) {
   // Default Styles To Pass Down To Bar Children
-  defaults.global.defaultFontFamily = "Trebuchet MS";
+  defaults.global.defaultFontFamily = "Nunito";
   defaults.global.defaultFontColor = "#242424";
   defaults.global.defaultFontSize = 24;
 
   const options = {
     legend: {
+      display: true,
+      align: "end",
+
       labels: {
-        fontSize: 20,
+        boxWidth: 0,
       },
     },
     scales: {
@@ -34,9 +34,7 @@ function BarChart(props) {
         {
           scaleLabel: {
             display: true,
-            labelString: "Time",
-
-            fontSize: 20,
+            labelString: "Time (seconds)",
           },
           ticks: {},
         },
@@ -46,20 +44,16 @@ function BarChart(props) {
           scaleLabel: {
             display: true,
             labelString: "Channel",
-            fontSize: 20,
-          },
-          ticks: {
-            fontSize: 20,
           },
+          ticks: {},
         },
       ],
     },
     tooltips: {
       callbacks: {
         label: function (t, d) {
-          let xLabel = d.datasets[t.datasetIndex].label;
           let yLabel = d.datasets[t.datasetIndex].data[t.index];
-          return xLabel + ": " + yLabel;
+          return yLabel.toFixed(5) + " seconds";
         },
       },
     },
@@ -71,7 +65,7 @@ function BarChart(props) {
     labels: labels,
     datasets: [
       {
-        label: "Execution Time",
+        label: "* Default CPU",
         backgroundColor: poolColors(Object.keys(props.data).length),
         data: Object.values(props.data),
       },
@@ -79,19 +73,17 @@ function BarChart(props) {
   };
 
   return (
-    <Container className="container-fluid-side row ">
-      <Container
-        className="container-fluid-side row"
-        style={{ height: "500px" }}
-      >
-        <div>
-          <Bar data={time_state} options={options} height={600} width={900} />
+    <div>
+      <div className="chart-container">
+        <div className="bar-div">
+          <h2>Execution Time</h2>
+          <Bar data={time_state} options={options} height={200} />
         </div>
-      </Container>
-      {/*<Container className="container-fluid-side row custom-row">*/}
+      </div>
+      {/*<div className="container-fluid-side row custom-row">*/}
       {/*    <Bar data={acc_state} options={options}/>*/}
-      {/*</Container>*/}
-    </Container>
+      {/*</div>*/}
+    </div>
   );
 }
 
