@@ -1,3 +1,7 @@
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import { GeneralControlsBar } from "./styled/GeneralControlsBar";
 import React from "react";
 import ConfigUpload from "./ConfigUpload";
@@ -10,7 +14,7 @@ class ConfigButtons extends React.Component {
         <button
           className="button-generic"
           id="save-config-button"
-          title="Save Current Config"
+          title="Save Settings"
           onClick={(event) => this.props.saveConfig(event)}
         >
           <i className="fas fa-save" />
@@ -18,7 +22,7 @@ class ConfigButtons extends React.Component {
         <button
           className="button-generic"
           id="run-config-button"
-          title="Run All"
+          title="Run"
           onClick={(event) => this.props.runAll(event)}
         >
           <i className="fas fa-play" />
