@@ -1,37 +1,40 @@
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import React from "react";
-import { Container } from "../styled-components";
 import { ChannelHeadingContainer } from "./styled/ChannelHeadingContainer";
-import "./ColHeadings.css";
-function ColHeadings() {
+import AddChannel from "./AddChannel";
+
+function ColHeadings({ addChannel, channels }) {
   return (
     <div className="column-header">
       <ChannelHeadingContainer className="container-fluid-side row">
-        <Container className="card-heading is-light-text ">
-          {/* Div To Align Columns Properly */}
-          <div />
-        </Container>
-        <Container className="card-heading is-light-text ">
+        <div className="card-heading is-light-text ">
+          <AddChannel addChannel={addChannel} channels={channels} />
+        </div>
+        <div className="card-heading is-light-text ">
           <h2 className="is-dark-text-light letter-spacing text-medium">
             Data
           </h2>
-        </Container>
-        <Container className="card-heading is-light-text ">
+        </div>
+        <div className="card-heading is-light-text ">
           <h2 className="is-dark-text-light letter-spacing text-medium">
             Task
           </h2>
-        </Container>
-        <Container className="card-heading is-light-text ">
+        </div>
+        <div className="card-heading is-light-text ">
           <h2 className="is-dark-text-light letter-spacing text-medium">
             Model
           </h2>
-        </Container>
-        <Container className="card-heading is-light-text ">
+        </div>
+        <div className="card-heading is-light-text ">
           <h2 className="is-dark-text-light letter-spacing text-medium">
-            Preview
+            Sample
           </h2>
-        </Container>
+        </div>
       </ChannelHeadingContainer>
-      {/* Div To Emulate Buttons Div */}
+      {/* Div To Emulate Buttons Div Spacing */}
       <div className="fill-block" />
     </div>
   );
