@@ -1,10 +1,13 @@
-import { Container } from "../styled-components";
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import React, { Component } from "react";
 
 class ModelSelect extends Component {
   render() {
     return (
-      <Container>
+      <div>
         <div id={"model-" + this.props.formId}>
           <select
             className="custom-select"
@@ -15,9 +18,9 @@ class ModelSelect extends Component {
           >
             {/* Have we selected our task yet? */}
             {this.props.models.length === 0 ? (
-              <option defaultValue>(Select Task First)</option>
+              <option defaultValue>Select Task First</option>
             ) : (
-              <option defaultValue>(Select A Model)</option>
+              <option defaultValue>Select A Model</option>
             )}
             {/* Mapping over available models */}
             {this.props.models &&
@@ -28,7 +31,7 @@ class ModelSelect extends Component {
               ))}
           </select>
         </div>
-      </Container>
+      </div>
     );
   }
 }
