@@ -1,8 +1,11 @@
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import styled from "styled-components";
 
-// The full-width columns contain an extra 50px as a buffer
-// due to the lower channels having a 50px wide button div on the right
 export const ChannelHeadingContainer = styled.div`
+  font-family: "Nunito", sans-serif;
   width: 92%;
   display: grid;
   justify-content: space-between;
@@ -11,7 +14,7 @@ export const ChannelHeadingContainer = styled.div`
   grid-template-columns: 5% 10% 15% 15% 45%;
   grid-template-rows: 75px;
 
-  @media (max-width: 1195px) {
+  @media (max-width: 1275px) {
     width: 100%;
   }
 `;
