@@ -1,3 +1,7 @@
+// Copyright (c) FlapMX LLC.
+// This source code is licensed under the MIT license found in the
+// LICENSE file in the root directory of this source tree.
+
 import React, { useState, useEffect } from "react";
 import BarChart from "../components/BarChart";
 
@@ -7,9 +11,10 @@ function Metrics(props) {
   const populateEmptyIndices = (time_obj) => {
     const newTimes = { ...time_obj };
     const keys = Object.keys(newTimes);
-    const maxKey = Math.max(keys);
+    const keysToNumber = keys.map((key) => parseInt(key, 10));
 
-    for (let i = 0; i < maxKey; i++) {
+    const maxKey = Math.max(...keysToNumber);
+    for (let i = 0; i <= maxKey; i++) {
       if (!newTimes[i]) {
         newTimes[i] = 0;
       }
